Index: /CKEditor/trunk/CHANGES.html
===================================================================
--- /CKEditor/trunk/CHANGES.html	(revision 6264)
+++ /CKEditor/trunk/CHANGES.html	(revision 6265)
@@ -52,4 +52,5 @@
 		<li><a href="http://dev.ckeditor.com/ticket/6686">#6686</a> : BIDI:[FF] when we apply explicit language direction to Numbered/Bulleted List the corresponding BIDI Tool bar icon is not highlighted in the Toolbar.</li>
 		<li><a href="http://dev.ckeditor.com/ticket/6566">#6566</a> : It is now possible to exit blockquote with enterMode BR.</li>
+		<li><a href="http://dev.ckeditor.com/ticket/6868">#6868</a> : Partial (invalid) list structure crashes editor load.</li>
 	</ul>
 	<h3>
Index: /CKEditor/trunk/_source/core/htmlparser/fragment.js
===================================================================
--- /CKEditor/trunk/_source/core/htmlparser/fragment.js	(revision 6264)
+++ /CKEditor/trunk/_source/core/htmlparser/fragment.js	(revision 6265)
@@ -119,5 +119,5 @@
 			target = target || currentNode || fragment;
 
 			// If the target is the fragment and this element can't go inside
 			// body (if fixForBody).
 			if ( fixForBody && !target.type )
@@ -130,7 +130,6 @@
 				else
 					elementName =  element.name;
-				if ( elementName
-						&& !( elementName in CKEDITOR.dtd.$body )
-						&& !( elementName in CKEDITOR.dtd.$nonBodyContent )  )
+
+				if ( elementName && elementName in CKEDITOR.dtd.$inline )
 				{
 					var savedCurrent = currentNode;
@@ -119,5 +119,5 @@
 			target = target || currentNode || fragment;
 
-			// If the target is the fragment and this element can't go inside
+			// If the target is the fragment and this inline element can't go inside
 			// body (if fixForBody).
 			if ( fixForBody && !target.type )
